==> dokuwiki-2012.01.25.tgz: dokuwiki/lib/plugins/acl/lang/hr/lang.php <==
<?php
/**
 * Croatian language file
 *
 * @author Branko Rihtman <theney@gmail.com>
 * @author Dražen Odobašić <dodobasic@gmail.com>
 * @author Dejan Igrec dejan.igrec@gmail.com
 */
$lang['admin_acl']             = 'Upravljanje listom kontrole pristupa';
$lang['acl_group']             = 'Grupa';
$lang['acl_user']              = 'Korisnik';
$lang['acl_perms']             = 'Dozvole za';
$lang['page']                  = 'Stranica';
$lang['namespace']             = 'Imenski prostor';
$lang['btn_select']            = 'Odaberi';
$lang['p_user_id']             = 'Korisnik <b class="acluser">%s</b> trenutno ima sljedeće dozvole na stranici <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Korisnik <b class="acluser">%s</b> trenutno ima sljedeće dozvole u imenskom prostoru <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Članovi grupe <b class="aclgroup">%s</b> trenutno imaju sljedeće dozvole na stranici <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Članovi grupe <b class="aclgroup">%s</b> trenutno imaju sljedeće dozvole u imenskom prostoru <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Molim <b>unesti korisnika ili grupu</b> u gornju formu za pregled ili uređivanje dozvola postavljenih za stranicu <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Molim <b>unesti korisnika ili grupu</b> u gornju formu za pregled ili uređivanje dozvola postavljenih za imenski prostor <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Napomena: Ove dozvole nisu postavljene eksplicitno već su naslijeđene od drugih grupa ili nadređenih imenskih prostora.';
$lang['p_isadmin']             = 'Napomena: Odabrana grupa ili korisnik uvijek ima sve dozvole jer je postavljen kao superuser.';
$lang['p_include']             = 'Više dozvole uključuju sve niže. Dozvole Kreiraj, Učitaj i Briši se primjenjuju samo na imenske prostore, ne stranice.';
$lang['current']               = 'Trenutna ACL Pravila';
$lang['where']                 = 'Stranica/Imenski prostor';
$lang['who']                   = 'Korisnik/Grupa';
$lang['perm']                  = 'Dozvole';
$lang['acl_perm0']             = 'Ništa';
$lang['acl_perm1']             = 'Čitaj';
$lang['acl_perm2']             = 'Uredi';
$lang['acl_perm4']             = 'Kreiraj';
$lang['acl_perm8']             = 'Učitaj';
$lang['acl_perm16']            = 'Briši';
$lang['acl_new']               = 'Dodaj novi Zapis';
$lang['acl_mod']               = 'Promijeni Zapis';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/acl/lang/hr/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Branko Rihtman <theney@gmail.com>
 * @author Dražen Odobašić <dodobasic@gmail.com>
 * @author Dejan Igrec <dejan.igrec@gmail.com>
 */
$lang['admin_acl']             = 'Upravljanje listom kontrole pristupa';
$lang['acl_group']             = 'Grupa:';
$lang['acl_user']              = 'Korisnik:';
$lang['acl_perms']             = 'Dozvole za';
$lang['page']                  = 'Stranica';
$lang['namespace']             = 'Imenski prostor';
$lang['btn_select']            = 'Odaberi';
$lang['p_user_id']             = 'Korisnik <b class="acluser">%s</b> trenutno ima sljedeće dozvole na stranici <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Korisnik <b class="acluser">%s</b> trenutno ima sljedeće dozvole u imenskom prostoru <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Članovi grupe <b class="aclgroup">%s</b> trenutno imaju sljedeće dozvole na stranici <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Članovi grupe <b class="aclgroup">%s</b> trenutno imaju sljedeće dozvole u imenskom prostoru <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Molim <b>unesti korisnika ili grupu</b> u gornju formu za pregled ili uređivanje dozvola postavljenih za stranicu <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Molim <b>unesti korisnika ili grupu</b> u gornju formu za pregled ili uređivanje dozvola postavljenih za imenski prostor <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Napomena: Ove dozvole nisu postavljene eksplicitno već su naslijeđene od drugih grupa ili nadređenih imenskih prostora.';
$lang['p_isadmin']             = 'Napomena: Odabrana grupa ili korisnik uvijek ima sve dozvole jer je postavljen kao superuser.';
$lang['p_include']             = 'Više dozvole uključuju sve niže. Dozvole Kreiraj, Učitaj i Briši se primjenjuju samo na imenske prostore, ne stranice.';
$lang['current']               = 'Trenutna ACL Pravila';
$lang['where']                 = 'Stranica/Imenski prostor';
$lang['who']                   = 'Korisnik/Grupa';
$lang['perm']                  = 'Dozvole';
$lang['acl_perm0']             = 'Ništa';
$lang['acl_perm1']             = 'Čitaj';
$lang['acl_perm2']             = 'Uredi';
$lang['acl_perm4']             = 'Kreiraj';
$lang['acl_perm8']             = 'Učitaj';
$lang['acl_perm16']            = 'Briši';
$lang['acl_new']               = 'Dodaj novi Zapis';
$lang['acl_mod']               = 'Promijeni Zapis';
